@@ -56,10 +56,10 @@ typedef struct CNode_s CNode;
 /* Invariant: Leaf if child==NULL */
 struct CNode_s
 {
-  char  * label;
-  CNode * child;
-  CNode * next;
-  int   start, end;
+	char  * label;
+	CNode * child;
+	CNode * next;
+	int   start, end;
 };
 
 /* ================================================================ */
@@ -329,7 +329,7 @@ static void adjust_subordinate_clauses(con_context_t *ctxt, Linkage linkage,
 			}
 			if (strcmp(linkage->word[ctxt->constituent[c].left], ",") == 0)
 				ctxt->constituent[c].left++;
-		}	
+		}
 	}
 }
 
@@ -393,7 +393,7 @@ static void generate_misc_word_info(con_context_t * ctxt, Linkage linkage)
 	for (w1 = 0; w1 < linkage->num_words; w1++)
 		ctxt->wordtype[w1] = NONE;
 
-	for (l1 = 0; l1 < linkage_get_num_links(linkage); l1++) {	
+	for (l1 = 0; l1 < linkage_get_num_links(linkage); l1++) {
 		w1=linkage_get_link_rword(linkage, l1);
 		label1 = linkage_get_link_label(linkage, l1);
 		if ((uppercompare(label1, "S")==0) ||
@@ -435,7 +435,7 @@ static int new_style_conjunctions(con_context_t *ctxt, Linkage linkage, int numc
 	for (c = 0; c < numcon_total; c++)
 	{
 		constituent_t *ct = &ctxt->constituent[c];
-		lgdebug(3, "ola %d valid=%d %s start=%s lr=%zu %zu\n", c, 
+		lgdebug(3, "ola %d valid=%d %s start=%s lr=%zu %zu\n", c,
 			ct->valid, ct->type, ct->start_link, ct->left, ct->right);
 	}
 #endif
@@ -533,7 +533,7 @@ static int last_minute_fixes(con_context_t *ctxt, Linkage linkage, int numcon_to
 			size_t ln;
 			for (ln = 0; ln < linkage->num_links; ln++)
 			{
-				if ((linkage->link_array[ln].lw == linkage->num_words - 2) && 
+				if ((linkage->link_array[ln].lw == linkage->num_words - 2) &&
 				    (linkage->link_array[ln].rw == linkage->num_words - 1))
 				{
 					ctxt->constituent[c].right++;
@@ -551,7 +551,7 @@ static int last_minute_fixes(con_context_t *ctxt, Linkage linkage, int numcon_to
 	global_rightend_found = false;
 	for (c = 0; c < numcon_total; c++)
 	{
-		if ((ctxt->constituent[c].left == 1) && 
+		if ((ctxt->constituent[c].left == 1) &&
 		   (strcmp(ctxt->constituent[c].type, "S") == 0) &&
 			ctxt->constituent[c].valid)
 		{
@@ -651,7 +651,7 @@ static const char * cons_of_domain(const Linkage linkage, char domain_type)
 		return "VP";
 	default:
 		{
-			err_ctxt ec;
+			err_ctxt ec = { linkage->sent };
 			err_msg(&ec, Error, "Error: Illegal domain: %c\n", domain_type);
 			return "";
 		}
@@ -663,14 +663,15 @@ static int read_constituents_from_domains(con_context_t *ctxt, Linkage linkage,
 {
 	size_t d, l, w2;
 	int c, w, c2, numcon_subl = 0;
+	PP_data *pp_data = &linkage->sent->constituent_pp->pp_data;
 
-	for (d = 0, c = numcon_total; d < linkage->hpsg_pp_data.N_domains; d++, c++)
+	for (d = 0, c = numcon_total; d < pp_data->N_domains; d++, c++)
 	{
 		size_t leftmost, rightmost, leftlimit;
 		int rootleft;
 		List_o_links * dlink;
 
-		Domain domain = linkage->hpsg_pp_data.domain_array[d];
+		Domain domain = pp_data->domain_array[d];
 
 		// rootright = linkage_get_link_rword(linkage, domain.start_link);
 		rootleft =  linkage_get_link_lword(linkage, domain.start_link);
@@ -807,12 +808,12 @@ static int read_constituents_from_domains(con_context_t *ctxt, Linkage linkage,
 
 		if (ctxt->constituent[c].domain_type == '\0')
 		{
-			err_ctxt ec;
+			err_ctxt ec = { linkage->sent };
 			err_msg(&ec, Error, "Error: no domain type assigned to constituent\n");
 		}
 		if (ctxt->constituent[c].start_link == NULL)
 		{
-			err_ctxt ec;
+			err_ctxt ec = { linkage->sent };
 			err_msg(&ec, Error, "Error: no type assigned to constituent\n");
 		}
 	}
@@ -917,8 +918,8 @@ static int read_constituents_from_domains(con_context_t *ctxt, Linkage linkage,
 					{
 						if (verbosity >= 2)
 						{
-							err_ctxt ec;
-							err_msg(&ec, Warn, 
+							err_ctxt ec = { linkage->sent };
+							err_msg(&ec, Warn,
 							      "Warning: the constituents aren't nested! "
 							      "Adjusting them. (%d, %d)\n", c, c2);
 					  }
@@ -934,7 +935,7 @@ static int read_constituents_from_domains(con_context_t *ctxt, Linkage linkage,
 	return numcon_subl;
 }
 
-static char * 
+static char *
 exprint_constituent_structure(con_context_t *ctxt,
                               Linkage linkage, int numcon_total)
 {
@@ -956,7 +957,7 @@ exprint_constituent_structure(con_context_t *ctxt,
 	}
 
 	if (verbosity >= 2)
-		printf("\n");			
+		printf("\n");
 
 	/* Skip left wall; don't skip right wall, since it may
 	 * have constituent boundaries. */
@@ -1011,6 +1012,12 @@ exprint_constituent_structure(con_context_t *ctxt,
 				p = strchr(p, CLOSE_BRACKET);
 			}
 
+#if 0 /* firstupper check removed in 0c8107a */
+			/* Now, if the first character of the word was
+			   originally uppercase, we put it back that way */
+			if (linkage->chosen_disjuncts[w]->word[0]->status & WS_FIRSTUPPER)
+				upcase_utf8_str(s, s, MAX_WORD);
+#endif
 			append_string(cs, "%s ", s);
 		}
 
@@ -1042,14 +1049,23 @@ exprint_constituent_structure(con_context_t *ctxt,
 
 static char * do_print_flat_constituents(con_context_t *ctxt, Linkage linkage)
 {
-	int numcon_total, numcon_subl;
+	int numcon_total= 0, numcon_subl;
 	char * q;
+	Sentence sent = linkage->sent;
 
+	assert(NULL != sent->lnkages, "No linkages"); /* Sentence already free()'d */
 	ctxt->phrase_ss = string_set_create();
-	numcon_total = 0;
-
 	generate_misc_word_info(ctxt, linkage);
 
+	if (NULL ==  sent->constituent_pp)         /* First time for this sentence */
+		sent->constituent_pp = post_process_new(sent->dict->hpsg_knowledge);
+
+	do_post_process(sent->constituent_pp, linkage, linkage->is_sent_long);
+
+	/** No-op. If we wanted to debug domain names, we could do this...
+	 * linkage_free_pp_info(linkage);
+	 * linkage_set_domain_names(sent->constituent_pp, linkage);
+	 */
 	numcon_subl = read_constituents_from_domains(ctxt, linkage, numcon_total);
 	numcon_total += numcon_subl;
 	assert (numcon_total < ctxt->conlen, "Too many constituents (c)");
@@ -1062,6 +1078,9 @@ static char * do_print_flat_constituents(con_context_t *ctxt, Linkage linkage)
 	q = exprint_constituent_structure(ctxt, linkage, numcon_total);
 	string_set_delete(ctxt->phrase_ss);
 	ctxt->phrase_ss = NULL;
+
+	post_process_free_data(&sent->constituent_pp->pp_data);
+
 	return q;
 }
 
@@ -1242,8 +1261,10 @@ static CNode * linkage_constituent_tree(Linkage linkage)
 }
 
 /* Make the compiler shut up about the deprecated functions */
+/*
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+*/
 
 static void linkage_free_constituent_tree(CNode * n)
 {
@@ -1260,7 +1281,7 @@ static void linkage_free_constituent_tree(CNode * n)
  * Print out the constituent tree.
  * mode 1: treebank-style constituent tree
  * mode 2: flat, bracketed tree [A like [B this B] A]
- * mode 3: flat, treebank-style tree (A like (B this) )
+ * mode 3: flat, treebank-style tree (A like (B this))
  */
 char * linkage_print_constituent_tree(Linkage linkage, ConstituentDisplayStyle mode)
 {
@@ -1288,7 +1309,8 @@ char * linkage_print_constituent_tree(Linkage linkage, ConstituentDisplayStyle m
 	{
 		return print_flat_constituents(linkage);
 	}
-	assert(0, "Illegal mode in linkage_print_constituent_tree");
+	prt_error("Warning: Illegal mode %d for printing constituents\n"
+	          "Allowed values: %d to %d\n", mode, NO_DISPLAY, MAX_STYLES);
 	return NULL;
 }
 
@@ -1296,4 +1318,3 @@ void linkage_free_constituent_tree_str(char * s)
 {
 	exfree(s, strlen(s)+1);
 }
-
