@@ -13,7 +13,7 @@
 
 
 #include <stdint.h>
-#include <malloc.h>
+#include <stdlib.h>
 
 #include "externs.h"
 #include "api-structures.h"
